# Examples demonstrating the use of the formalism described by Klatt & Polerecky (2015) 
# doi: 10.3389/fmicb.2015.00484

# Calculate efficiency of autotrophic sulfur oxidation from the known stoichiometry, where
# stoichiometry is completely determined by the parameters x and y

# load the functions
source('SOX_functions.R')

#######################################
# Aerobic autotrophic sulfur oxidation
#######################################

# efficiency of aerobic thiosulfate oxidation by Thioalkalivibrio versutus: 
# data from Sorokin et al. (2001) imply x=0 and y=0.844, C-fixation through Calvin cycle; 
x <- 0; y <- 0.844
# efficiency at std biochemical conditions, traditional and new approach
(e1 <- aerob_efficiency(x,y,Sred="S2O3",approach=1)$eff)
(e2 <- aerob_efficiency(x,y,Sred="S2O3",approach=2,Cfix="Calvin")$eff)
# by omitting $eff, the partial efficiencies together with the Gibbs free energies and quotient Q
# will be also returned
(e3 <- aerob_efficiency(x,y,Sred="S2O3",approach=2,Cfix="Calvin"))
# by specifying the concentrations of the reactants involved, one can calculate the efficiency
# at non-standard conditions
(e3b <- aerob_efficiency(x,y,Sred="S2O3",approach=2,Cfix="Calvin",S=30e-6,
          sulfate=20e-3,O2=100e-6,CO2=2.5e-3,NAD=1e-3,NADH=1e-3,pH=6, Temp=15))

# efficiency of aerobic thiosulfate oxidation by Thermithiobacillus tepidarius:
# data from Wood and Kelly (1986) imply x=0 and y=0.804, C-fixation through Calvin cycle;
x <- 0; y <- 0.804
# efficiency at std biochemical conditions, traditional and new approach
(e4 <- aerob_efficiency(x,y,Sred="S2O3",approach=1)$eff)
(e5 <- aerob_efficiency(x,y,Sred="S2O3",approach=2,Cfix="Calvin")$eff)
# by omitting $eff, the partial efficiencies together with the Gibbs free energies and quotient Q
# will be also returned
(e6 <- aerob_efficiency(x,y,Sred="S2O3",approach=2,Cfix="Calvin"))
# by specifying the concentrations of the reactants involved, one can calculate the efficiency
# at non-standard conditions
(e6b <- aerob_efficiency(x,y,Sred="S2O3",approach=2,Cfix="Calvin",S=30e-6,
          sulfate=20e-3,O2=100e-6,CO2=2.5e-3,NAD=1e-3,NADH=1e-3,pH=6, Temp=15))

###########################################################
# Autotrophic sulfur oxidation coupled to denitrification
###########################################################

# efficiency of anaerobic thiosulfate oxidation coupled to denitrifiction by Sulfurimonas denitrificans: 
# data from Hoor (1981) imply x=0 and y=0.902, C-fixation through rTCA cycle;  
x <- 0; y <- 0.902
# efficiency at std conditions, traditional and new approach
(e1 <- denit_efficiency(x,y,Sred="S2O3",approach=1)$eff)
(e2 <- denit_efficiency(x,y,Sred="S2O3",approach=2,Cfix="rTCA")$eff)
# by omitting $eff, the partial efficiencies together with the Gibbs free energies and quotient Q
# will be also returned
(e3 <- denit_efficiency(x,y,Sred="S2O3",approach=2,Cfix="rTCA"))
# by specifying the concentrations of the reactants involved, one can calculate the efficiency
# at non-standard conditions
(e3b <- denit_efficiency(x,y,Sred="S2O3",approach=2,Cfix="rTCA", S=30e-6,
        sulfate=20e-3,NO3=100e-6,N2=10e-3,CO2=2.5e-3,NAD=1e-3,NADH=1e-3,Fdox=1e-3,
        Fdred=1e-3,FAD=1e-3,FADH2=1e-3,pH=6, Temp=15))
